@@ -9,7 +9,7 @@ package PDF::Table;
 
 # portions (c) copyright 2004 Stone Environmental Inc.
 # (c) copyright 2006 Daemmon Hughes
-# (c) copyright 2020 - 2023 by Phil M. Perry
+# (c) copyright 2020 - 2025 by Phil M. Perry
  
 use Carp;
 use List::Util qw[min max];  # core
@@ -18,8 +18,8 @@ use PDF::Table::ColumnWidth;
 use PDF::Table::Settings;
 # can't move text_block() b/c many globals referenced
 
-our $VERSION = '1.005'; # fixed, read by Makefile.PL
-our $LAST_UPDATE = '1.005'; # manually update whenever code is changed
+our $VERSION = '1.007'; # fixed, read by Makefile.PL
+our $LAST_UPDATE = '1.007'; # manually update whenever code is changed
 # don't forget to update VERSION down in POD area
 
 my $compat_mode = 0; # 0 = new behaviors, 1 = compatible with old
@@ -335,7 +335,7 @@ sub table {
         $header_props = $arg{'header_props'};
 
         # Check other parameters and put defaults if needed
-        $header_props->{'repeat'   } ||= $repeat_default;
+        $header_props->{'repeat'   } //= $repeat_default;
 
         $do_headers = 1;  # do headers, no repeat
         $do_headers = 2 if $header_props->{'repeat'};  # do headers w/ repeat
@@ -1141,14 +1141,20 @@ sub table {
                 $data_row->[$col_idx] //= $cell_def_text;
 
                 # Handle colspan
-                my $c_cell_props = $cell_props->[$row_idx][$col_idx];
+                my $c_cell_props = $is_header_row ?
+                    $cell_props->[0][$col_idx] :
+                    $cell_props->[$row_idx][$col_idx];
                 my $this_cell_width = $calc_column_widths->[$col_idx];
                 if ($c_cell_props && $c_cell_props->{'colspan'} && $c_cell_props->{'colspan'} > 1) {
                     my $colspan = $c_cell_props->{'colspan'};
                     for my $offset (1 .. $colspan - 1) {
                         $this_cell_width += $calc_column_widths->[$col_idx + $offset] 
                             if $calc_column_widths->[$col_idx + $offset];
-                        $colspanned{$row_idx.'_'.($col_idx + $offset)} = 1;
+                        if ($is_header_row) {
+                            $colspanned{'0_'.($col_idx + $offset)} = 1;
+                        } else {
+                            $colspanned{$row_idx.'_'.($col_idx + $offset)} = 1;
+                        }
                     }
                 }
                 $this_cell_width = max($this_cell_width, $min_col_width);
@@ -1330,6 +1336,7 @@ sub table {
         # TBD rowspan!
                 if ($ink) {
                     if (defined $bg_color && 
+                        $bg_color ne 'transparent' && $bg_color ne 'trans' &&
                         !$colspanned{$row_idx.'_'.$col_idx}) {
                         $gfx_bg->rect( $cur_x, $cur_y-$actual_row_height,  
                                        $actual_column_widths[$row_idx][$col_idx], $actual_row_height);
